summaryrefslogtreecommitdiff
path: root/shared-bindings/supervisor/RunReason.c
diff options
context:
space:
mode:
authorDan Halbert <halbert@halwitz.org>2020-11-22 19:10:09 -0500
committerDan Halbert <halbert@halwitz.org>2020-11-22 19:10:09 -0500
commita0f1ec3c4a3dd52b11752e10d0dd31202e9c705f (patch)
tree333234f72abc302da7646f87a3c18740170b6bf7 /shared-bindings/supervisor/RunReason.c
parent75559f35ccc946dfd292e25671919e5d5b3bd7a6 (diff)
wip
Diffstat (limited to 'shared-bindings/supervisor/RunReason.c')
-rw-r--r--shared-bindings/supervisor/RunReason.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/shared-bindings/supervisor/RunReason.c b/shared-bindings/supervisor/RunReason.c
index ee08f6d71..7e7a74d2f 100644
--- a/shared-bindings/supervisor/RunReason.c
+++ b/shared-bindings/supervisor/RunReason.c
@@ -29,7 +29,7 @@
#include "shared-bindings/supervisor/RunReason.h"
MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, STARTUP, RUN_REASON_STARTUP);
-MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, AUTORELOAD, RUN_REASON_AUTORELOAD);
+MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, AUTORELOAD, RUN_REASON_AUTO_RELOAD);
MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, SUPERVISOR_RELOAD, RUN_REASON_SUPERVISOR_RELOAD);
MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, REPL_RELOAD, RUN_REASON_REPL_RELOAD);
@@ -40,8 +40,8 @@ MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, REPL_RELOAD, RUN_REASON_
//| """CircuitPython started the microcontroller started up. See `microcontroller.cpu.reset_reason`
//| for more detail on why the microcontroller was started."""
//|
//| AUTORELOAD: object
//| """CircuitPython restarted due to a USB write to the filesystem."""
//|
//| SUPERVISOR_RELOAD: object
//| """CircuitPython restarted due to a call to `supervisor.reload()`."""
@@ -51,7 +51,7 @@ MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, REPL_RELOAD, RUN_REASON_
//|
MAKE_ENUM_MAP(run_reason) {
MAKE_ENUM_MAP_ENTRY(run_reason, STARTUP),
- MAKE_ENUM_MAP_ENTRY(run_reason, AUTORELOAD),
+ MAKE_ENUM_MAP_ENTRY(run_reason, AUTO_RELOAD),
MAKE_ENUM_MAP_ENTRY(run_reason, SUPERVISOR_RELOAD),
MAKE_ENUM_MAP_ENTRY(run_reason, REPL_RELOAD),
};
@@ -40,8 +40,8 @@ MAKE_ENUM_VALUE(supervisor_run_reason_type, run_reason, REPL_RELOAD, RUN_REASON_
//| for more detail on why the microcontroller was started."""
//|
-//| AUTORELOAD: object
-//| """CircuitPython restarted due to a USB write to the filesystem."""
+//| AUTO_RELOAD: object
+//| """CircuitPython restarted due to an external write to the filesystem."""
//|
//| SUPERVISOR_RELOAD: object